pub struct KeySetOptions {
pub mnemonic: Option<Mnemonic<English>>,
pub index: Option<u64>,
pub key_file: Option<PathBuf>,
pub private_staking_key: Option<TaggedBase64>,
pub private_state_key: Option<TaggedBase64>,
pub private_x25519_key: Option<TaggedBase64>,
}Expand description
Keys can be specified in one of three ways:
- A mnemonic phrase
- A path to a key file
- Individual private keys set via environment variable
Note that the third option always takes precedence, but if not all keys are specified explicitly in this way, one of the first two options may be used to generate the remaining keys.
Fields
mnemonic: Option<Mnemonic<English>>Mnemonic phrase used to generate keys.
index: Option<u64>Optional index to enable generating multiple keysets from the same mnemonic.
key_file: Option<PathBuf>Path to file containing private keys.
The file should follow the .env format, with two keys:
- ESPRESSO_SEQUENCER_PRIVATE_STAKING_KEY
- ESPRESSO_SEQUENCER_PRIVATE_STATE_KEY
Appropriate key files can be generated with the keygen utility program.
private_staking_key: Option<TaggedBase64>Private staking key.
This can be used as an alternative to MNEMONIC or KEY_FILE.
private_state_key: Option<TaggedBase64>Private state signing key.
This can be used as an alternative to MNEMONIC or KEY_FILE.
private_x25519_key: Option<TaggedBase64>Private x25519 key.
This can be used as an alternative to MNEMONIC or KEY_FILE.